tzif examples
Within the examples directory are some simple examples of how to use the tzif
library.
-
simple
shows a program converting the current system time to the America/New_York
timezone and writing the result including the timezone designation.
-
time_now
will iterate through the available timezones and print the current time in each
timezone available in the system timezone database.